@@ -16,9 +16,9 @@ graph_extract_components(zachary)
 
 ## ------------------------------------------------------------------------
 
-data(drugtarget)
+data("drugTarget")
 
-drug_comp <- graph_extract_components( drugtarget, directed = TRUE , bipartite_proj=TRUE, num_proj=2)
+drug_comp <- graph_extract_components( drugTarget, directed = TRUE , bipartite_proj=TRUE, num_proj=2)
 head(drug_comp)
 
 
